==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/notificationhubs/kotlin/inputs/WnsCredentialPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.notificationhubs.kotlin.inputs

import com.pulumi.azurenative.notificationhubs.inputs.WnsCredentialPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Description of a NotificationHub WnsCredential.
 * @property certificateKey Ges or sets the WNS Certificate Key.
 * @property packageSid Gets or sets the package ID for this credential.
 * @property secretKey Gets or sets the secret key.
 * @property windowsLiveEndpoint Gets or sets the Windows Live endpoint.
 * @property wnsCertificate Gets or sets the WNS Certificate.
 */
public data class WnsCredentialPropertiesArgs(
    public val certificateKey: Output<String>? = null,
    public val packageSid: Output<String>? = null,
    public val secretKey: Output<String>? = null,
    public val windowsLiveEndpoint: Output<String>? = null,
    public val wnsCertificate: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.notificationhubs.inputs.WnsCredentialPropertiesArgs> {
    override fun toJava(): com.pulumi.azurenative.notificationhubs.inputs.WnsCredentialPropertiesArgs =
        com.pulumi.azurenative.notificationhubs.inputs.WnsCredentialPropertiesArgs.builder()
            .certificateKey(certificateKey?.applyValue({ args0 -> args0 }))
            .packageSid(packageSid?.applyValue({ args0 -> args0 }))
            .secretKey(secretKey?.applyValue({ args0 -> args0 }))
            .windowsLiveEndpoint(windowsLiveEndpoint?.applyValue({ args0 -> args0 }))
            .wnsCertificate(wnsCertificate?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [WnsCredentialPropertiesArgs].
 */
@PulumiTagMarker
public class WnsCredentialPropertiesArgsBuilder internal constructor() {
    private var certificateKey: Output<String>? = null

    private var packageSid: Output<String>? = null

    private var secretKey: Output<String>? = null

    private var windowsLiveEndpoint: Output<String>? = null

    private var wnsCertificate: Output<String>? = null

    /**
     * @param value Ges or sets the WNS Certificate Key.
     */
    @JvmName("boyjpciytdojlepi")
    public suspend fun certificateKey(`value`: Output<String>) {
        this.certificateKey = value
    }

    /**
     * @param value Gets or sets the package ID for this credential.
     */
    @JvmName("iifvxsmcaqwenplg")
    public suspend fun packageSid(`value`: Output<String>) {
        this.packageSid = value
    }

    /**
     * @param value Gets or sets the secret key.
     */
    @JvmName("jbqmjvjbgjtbmovk")
    public suspend fun secretKey(`value`: Output<String>) {
        this.secretKey = value
    }

    /**
     * @param value Gets or sets the Windows Live endpoint.
     */
    @JvmName("nmyxctsctfrsaefx")
    public suspend fun windowsLiveEndpoint(`value`: Output<String>) {
        this.windowsLiveEndpoint = value
    }

    /**
     * @param value Gets or sets the WNS Certificate.
     */
    @JvmName("rxkkqpjbkyhagfdv")
    public suspend fun wnsCertificate(`value`: Output<String>) {
        this.wnsCertificate = value
    }

    /**
     * @param value Ges or sets the WNS Certificate Key.
     */
    @JvmName("xddmnamiulsqyaoa")
    public suspend fun certificateKey(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.certificateKey = mapped
    }

    /**
     * @param value Gets or sets the package ID for this credential.
     */
    @JvmName("bxwjldfnegjmvtnt")
    public suspend fun packageSid(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.packageSid = mapped
    }

    /**
     * @param value Gets or sets the secret key.
     */
    @JvmName("acbbubawavsfxbsu")
    public suspend fun secretKey(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.secretKey = mapped
    }

    /**
     * @param value Gets or sets the Windows Live endpoint.
     */
    @JvmName("qwtpvxgnqofoebsh")
    public suspend fun windowsLiveEndpoint(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.windowsLiveEndpoint = mapped
    }

    /**
     * @param value Gets or sets the WNS Certificate.
     */
    @JvmName("igsehuwfgnsrqxpk")
    public suspend fun wnsCertificate(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.wnsCertificate = mapped
    }

    internal fun build(): WnsCredentialPropertiesArgs = WnsCredentialPropertiesArgs(
        certificateKey = certificateKey,
        packageSid = packageSid,
        secretKey = secretKey,
        windowsLiveEndpoint = windowsLiveEndpoint,
        wnsCertificate = wnsCertificate,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/notificationhubs/kotlin/inputs/WnsCredentialPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.notificationhubs.kotlin.inputs

import com.pulumi.azurenative.notificationhubs.inputs.WnsCredentialPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Description of a NotificationHub WnsCredential.
 * @property certificateKey Ges or sets the WNS Certificate Key.
 * @property packageSid Gets or sets the package ID for this credential.
 * @property secretKey Gets or sets the secret key.
 * @property windowsLiveEndpoint Gets or sets the Windows Live endpoint.
 * @property wnsCertificate Gets or sets the WNS Certificate.
 */
public data class WnsCredentialPropertiesArgs(
    public val certificateKey: Output<String>? = null,
    public val packageSid: Output<String>? = null,
    public val secretKey: Output<String>? = null,
    public val windowsLiveEndpoint: Output<String>? = null,
    public val wnsCertificate: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.notificationhubs.inputs.WnsCredentialPropertiesArgs> {
    override fun toJava(): com.pulumi.azurenative.notificationhubs.inputs.WnsCredentialPropertiesArgs =
        com.pulumi.azurenative.notificationhubs.inputs.WnsCredentialPropertiesArgs.builder()
            .certificateKey(certificateKey?.applyValue({ args0 -> args0 }))
            .packageSid(packageSid?.applyValue({ args0 -> args0 }))
            .secretKey(secretKey?.applyValue({ args0 -> args0 }))
            .windowsLiveEndpoint(windowsLiveEndpoint?.applyValue({ args0 -> args0 }))
            .wnsCertificate(wnsCertificate?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [WnsCredentialPropertiesArgs].
 */
@PulumiTagMarker
public class WnsCredentialPropertiesArgsBuilder internal constructor() {
    private var certificateKey: Output<String>? = null

    private var packageSid: Output<String>? = null

    private var secretKey: Output<String>? = null

    private var windowsLiveEndpoint: Output<String>? = null

    private var wnsCertificate: Output<String>? = null

    /**
     * @param value Ges or sets the WNS Certificate Key.
     */
    @JvmName("vpbwelrdjbbtwqhv")
    public suspend fun certificateKey(`value`: Output<String>) {
        this.certificateKey = value
    }

    /**
     * @param value Gets or sets the package ID for this credential.
     */
    @JvmName("eijxwpawaiyjmnqx")
    public suspend fun packageSid(`value`: Output<String>) {
        this.packageSid = value
    }

    /**
     * @param value Gets or sets the secret key.
     */
    @JvmName("avmgbsltxawiskgd")
    public suspend fun secretKey(`value`: Output<String>) {
        this.secretKey = value
    }

    /**
     * @param value Gets or sets the Windows Live endpoint.
     */
    @JvmName("tepfxdqpttkewnkq")
    public suspend fun windowsLiveEndpoint(`value`: Output<String>) {
        this.windowsLiveEndpoint = value
    }

    /**
     * @param value Gets or sets the WNS Certificate.
     */
    @JvmName("sklmufhnickieaux")
    public suspend fun wnsCertificate(`value`: Output<String>) {
        this.wnsCertificate = value
    }

    /**
     * @param value Ges or sets the WNS Certificate Key.
     */
    @JvmName("qjvvkhbjgadxuyhq")
    public suspend fun certificateKey(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.certificateKey = mapped
    }

    /**
     * @param value Gets or sets the package ID for this credential.
     */
    @JvmName("cyvgxqmluxoykurv")
    public suspend fun packageSid(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.packageSid = mapped
    }

    /**
     * @param value Gets or sets the secret key.
     */
    @JvmName("dipwhgawmatiikci")
    public suspend fun secretKey(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.secretKey = mapped
    }

    /**
     * @param value Gets or sets the Windows Live endpoint.
     */
    @JvmName("ljvunmvybfchcbyu")
    public suspend fun windowsLiveEndpoint(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.windowsLiveEndpoint = mapped
    }

    /**
     * @param value Gets or sets the WNS Certificate.
     */
    @JvmName("fjariehuxoioxvxr")
    public suspend fun wnsCertificate(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.wnsCertificate = mapped
    }

    internal fun build(): WnsCredentialPropertiesArgs = WnsCredentialPropertiesArgs(
        certificateKey = certificateKey,
        packageSid = packageSid,
        secretKey = secretKey,
        windowsLiveEndpoint = windowsLiveEndpoint,
        wnsCertificate = wnsCertificate,
    )
}
